..
    This file is part of Invenio.
    Copyright (C) 2015-2019 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.


====================
 Invenio-Files-REST
====================

.. image:: https://github.com/inveniosoftware/invenio-files-rest/workflows/CI/badge.svg
        :target: https://github.com/inveniosoftware/invenio-files-rest/actions?query=workflow%3ACI

.. image:: https://img.shields.io/coveralls/inveniosoftware/invenio-files-rest.svg
        :target: https://coveralls.io/r/inveniosoftware/invenio-files-rest

.. image:: https://img.shields.io/pypi/v/invenio-files-rest.svg
        :target: https://pypi.org/pypi/invenio-files-rest

.. image:: https://img.shields.io/github/license/inveniosoftware/invenio-files-rest.svg
        :target: https://github.com/inveniosoftware/invenio-files-rest/blob/master/LICENSE


Invenio-Files-REST is a files storage module. It allows you to store and
retrieve files in a similar way to Amazon S3 APIs.

Features:

 * Files storage with configurable storage backends
 * Secure REST APIs
 * Support for large file uploads and multipart upload.
 * Customizable access control
 * File integrity monitoring


Further documentation is available on https://invenio-files-rest.readthedocs.io/.
